@@ -80,20 +80,11 @@ QString NewsFeedPost::timeAsString() const
     }
 
     if (minutes && !hours) {
-        if (minutes == 1)
-            return tr("%1 minute ago").arg(minutes);
-        else
-            return tr("%1 minutes ago").arg(minutes);
+        return tr("%1m ago").arg(minutes);
     } else if (hours < 6 && minutes > 0) {
-        if (hours == 1)
-            return tr("1 hour %1 minutes ago").arg(minutes);
-        else
-            return tr("%1 hours %2 minutes ago").arg(hours).arg(minutes);
+        return tr("%1h %2m ago").arg(hours).arg(minutes);
     } else if (hours < 6 && minutes == 0) {
-        if (hours == 1)
-            return tr("1 hour ago");
-        else
-            return tr("%1 hours ago").arg(hours);
+        return tr("%1h ago").arg(hours);
     } else if (days < 8) { // See if it's in the past week
         switch (days) {
         case 0:
